@@ -2,12 +2,13 @@ import sys
 import os
 from urllib.parse import urlparse
 import json
+from dotenv import load_dotenv
+from datetime import time, datetime, timedelta, date
 script_directory = os.path.dirname(os.path.abspath(__file__))
 sys.path.append(os.path.join(script_directory, '..'))
 
-from dotenv import load_dotenv
-from datetime import time, datetime, timedelta, date
-from .constants import *  # noqa: E402¸
+from .constants import OBJECT_TO_INSERT_CODE, BRAND_NAME, ENVIRONMENT_NAME  # noqa: E402
+from .validate import validate_environment_name, validate_brand_name  # noqa: E402
 load_dotenv()
 from logger_local.Logger import Logger  # noqa: E402
 
@@ -80,7 +81,7 @@ def is_valid_time_range(time_range: tuple) -> bool:
 
 
 def validate_url(url):
-    if url is not None or url !="":
+    if url is not None or url != "":
         parsed_url = urlparse(url)
         return parsed_url.scheme and parsed_url.netloc
     return True
@@ -250,13 +251,13 @@ def is_datetime_in_datetime_range(check_datetime: datetime, datetime_range: tupl
     return is_datetime_in_datetime_range_result
 
 
-# TODO Align those methods with typescript-sdk https://github.com/circles-zone/typescript-sdk-remote-typescript-package/blob/dev/typescript-sdk/src/utils/index.ts
+# TODO Align those methods with typescript-sdk https://github.com/circles-zone/typescript-sdk-remote-typescript-package/blob/dev/typescript-sdk/src/utils/index.ts  # noqa501
 # TODO Take those three functions to a separate file http_response.py
 # TODO Shall we create also createInternalServerErrorHttpResponse(), createOkHttpResponse() like we have in TypeScript?
 
 # Former name was create_http_headers()
 def create_authorization_http_headers(user_jwt: str):
-    http_headers  = {
+    http_headers = {
         'Content-Type': 'application/json',
         'Authorization': f'Bearer {user_jwt}',
     }
@@ -266,8 +267,8 @@ def create_authorization_http_headers(user_jwt: str):
 def create_return_http_headers():
     return {
                 "Content-Type": "application/json",
-                "Access-Control-Allow-Origin": "*", 
-            } 
+                "Access-Control-Allow-Origin": "*",
+            }
 
 
 # https://google.github.io/styleguide/jsoncstyleguide.xml?showone=Property_Name_Format#Property_Name_Format
@@ -275,3 +276,13 @@ def create_http_body(body):
     # TODO console.warning() if the body is not a valid camelCase JSON
     # https://stackoverflow.com/questions/17156078/converting-identifier-naming-between-camelcase-and-underscores-during-json-seria
     return json.dumps(body)
+
+
+def get_brand_name():
+    validate_brand_name()
+    return BRAND_NAME
+
+
+def get_environment_name():
+    validate_environment_name()
+    return ENVIRONMENT_NAME
